﻿using System.Drawing;

using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid.Views.Grid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.gridView.InitializeView
            (
                false,                          // Multi Select
                GridMultiSelectMode.CellSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,   // Draw Focus Rect Style
                true,                           // Show Indicator
                true,                           // Show Column Headers
                true,                           // Allow Column Moving
                true,                           // Allow Column Resizing
                true,                           // Allow Filter
                true,                           // Allow Sort
                false,                          // Allow Cell Merge
                EditorShowMode.Default,         // Editor Show Mode
                false                           // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.gridView.OptionsView.ShowGroupPanel = true;

            this.gridView.OptionsView.ShowGroupedColumns = true;

            this.gridControl.DataSource = new nwindDataSetTableAdapters.CustomersTableAdapter().GetData();

            this.gridView.BestFitColumns();

            try
            {
                this.gridView.BeginSort();

                this.gridView.ClearGrouping();

                this.gridView.Columns["Country"].GroupIndex = 0;
                this.gridView.Columns["City"   ].GroupIndex = 1;
            }
            finally
            {
                this.gridView.EndSort();
            }

            this.gridView.ExpandAllGroups();

            this.gridView.GroupLevelStyle += gridView_GroupLevelStyle;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 뷰 그룹 레벨 스타일 설정하기 - gridView_GroupLevelStyle(sender, e)

        /// <summary>
        /// 그리드 뷰 그룹 레벨 스타일 설정하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_GroupLevelStyle(object sender, GroupLevelStyleEventArgs e)
        {
            if(e.Level == 0)
            {
                e.LevelAppearance.ForeColor = Color.WhiteSmoke;
                e.LevelAppearance.BackColor = Color.Salmon;
            }
            else
            {
                e.LevelAppearance.ForeColor = Color.FromArgb(50, 50, 50);
                e.LevelAppearance.BackColor = Color.LightSalmon;
            }
        }

        #endregion
    }
}